@@ -1,4 +1,6 @@
 from __future__ import division, print_function, absolute_import
+
+import os
 from timeit import time
 import warnings
 import cv2
@@ -22,7 +24,8 @@ np.random.seed(100)
 COLORS = np.random.randint(0, 255, size=(200, 3),
                            dtype="uint8")
 # deep_sort
-model_filename = 'model_data/market1501.pb'
+pwd = os.getcwd()
+model_filename = pwd + 'model_data/market1501.pb'
 
 
 yolo = YOLO()
@@ -65,7 +68,7 @@ class Sort:
             fourcc = cv2.VideoWriter_fourcc(*'MJPG')
             out = cv2.VideoWriter(result_path + '/' + filename + "_" + type + '_output.avi', fourcc, 15,
                                   (w, h))
-            list_file = open('detection.txt', 'w')
+            list_file = open(pwd + 'detection.txt', 'w')
             frame_index = -1
 
         fps = 0.0
