@@ -18,16 +18,18 @@ from PIL import Image, ImageFont, ImageDraw
 from Sort.yolo3.model import yolo_eval
 from Sort.yolo3.utils import letterbox_image
 import argparse
+pwd = os.getcwd()
 ap = argparse.ArgumentParser()
-ap.add_argument("-i", "--input",help="path to input video", default = "./test_video/det_t1_video_00315_test.avi")
+ap.add_argument("-i", "--input",help="path to input video", default = str(pwd).join("/test_video"
+                                                                                    "/det_t1_video_00315_test.avi"))
 ap.add_argument("-c", "--class",help="name of class", default = "person")
 args = vars(ap.parse_args())
 
 class YOLO(object):
     def __init__(self):
-        self.model_path = 'model_data/yolo.h5'
-        self.anchors_path = 'model_data/yolo_anchors.txt'
-        self.classes_path = 'model_data/coco_classes.txt'
+        self.model_path = pwd + '/model_data/yolo.h5'
+        self.anchors_path = pwd + '/model_data/yolo_anchors.txt'
+        self.classes_path = pwd + '/model_data/coco_classes.txt'
         #具体参数可实验后进行调整
         if args["class"] == 'person':
            self.score = 0.6 #0.8
